pub trait CANRead {
// Required methods
fn data(&self) -> &[u8] ⓘ;
fn dlc(&self) -> usize;
}Expand description
A trait providing methods for accessing the underlying bytes of some CAN-bus data.
pub trait CANRead {
// Required methods
fn data(&self) -> &[u8] ⓘ;
fn dlc(&self) -> usize;
}A trait providing methods for accessing the underlying bytes of some CAN-bus data.